@@ -30,6 +30,7 @@ __all__ = (
     "ChimeSDKMediaPipelinesServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -360,3 +361,4 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+RegionName = Literal["ap-southeast-1", "eu-central-1", "us-east-1", "us-west-2"]
